@@ -12,6 +12,7 @@ logger.addHandler(NullHandler())
 
 import time
 import threading
+import copy
 
 from pyagentx2.mib import MIB
 
@@ -37,7 +38,8 @@ class Updater(threading.Thread):
                 start_time = now
 
                 # Clean the temporal mib and update
-                _mib.clear()
+                _mib.data = copy.deepcopy(self.mib.data) # TODO maybe I need to do a hard copy to avoid modifying orignal MIB accidentaly
+                _mib.data_idx = copy.deepcopy(self.mib.data_idx) # TODO maybe I need to do a hard copy to avoid modifying orignal MIB accidentaly
                 self.update(_mib)
 
                 # Add to mib only those oids that belong to this updater
